@@ -55,18 +55,17 @@ class Bind extends DnsBase
 		$domains = $this->getDomainList();
 
 		if (empty($domains)) {
-			$this->logger->logAction(FroxlorLogger::CRON_ACTION, LOG_INFO, 'No domains found for nameserver-config, skipping...');
-			return;
-		}
-
-		$this->bindconf_file = '# ' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf' . "\n" . '# Created ' . date('d.m.Y H:i') . "\n" . '# Do NOT manually edit this file, all changes will be deleted after the next domain change at the panel.' . "\n\n";
-
-		foreach ($domains as $domain) {
-			if ($domain['is_child']) {
-				// domains that are subdomains to other main domains are handled by recursion within walkDomainList()
-				continue;
+			$this->logger->logAction(FroxlorLogger::CRON_ACTION, LOG_INFO, 'No domains found for nameserver-config, not creating any zones...');
+			$this->bindconf_file = '';
+		} else {
+			$this->bindconf_file = '# ' . Settings::Get('system.bindconf_directory') . 'froxlor_bind.conf' . "\n" . '# Created ' . date('d.m.Y H:i') . "\n" . '# Do NOT manually edit this file, all changes will be deleted after the next domain change at the panel.' . "\n\n";
+			foreach ($domains as $domain) {
+				if ($domain['is_child']) {
+					// domains that are subdomains to other main domains are handled by recursion within walkDomainList()
+					continue;
+				}
+				$this->walkDomainList($domain, $domains);
 			}
-			$this->walkDomainList($domain, $domains);
 		}
 
 		$bindconf_file_handler = fopen(FileDir::makeCorrectFile(Settings::Get('system.bindconf_directory') . '/froxlor_bind.conf'), 'w');
