@@ -104,17 +104,15 @@ class FroxlorLogger
 						self::$ml->pushHandler(new SyslogHandler('froxlor', LOG_USER, Logger::DEBUG));
 						break;
 					case 'file':
+						$setings_logfile = Settings::Get('logger.logfile');
+						if (empty($setings_logfile)) {
+							Settings::Set('logger.logfile', 'froxlor.log');
+						}
 						$logger_logfile = FileDir::makeCorrectFile(Froxlor::getInstallDir() . '/logs/' . Settings::Get('logger.logfile'));
 						// is_writable needs an existing file to check if it's actually writable
-						@touch($logger_logfile);
-						if (empty($logger_logfile) || !is_writable($logger_logfile)) {
-							Settings::Set('logger.logfile', 'froxlor.log');
-							$logger_logfile = FileDir::makeCorrectFile(Froxlor::getInstallDir() . '/logs/froxlor.log');
-							@touch($logger_logfile);
-							if (empty($logger_logfile) || !is_writable($logger_logfile)) {
-								// not writable in our own directory? Skip
-								break;
-							}
+						if (!@touch($logger_logfile) || !is_writable($logger_logfile)) {
+							// not writable in our own directory? Skip
+							break;
 						}
 						self::$ml->pushHandler(new StreamHandler($logger_logfile, Logger::DEBUG));
 						break;
