@@ -65,13 +65,6 @@ return [
 						'select_var' => $domains,
 						'selected' => $result['aliasdomain']
 					],
-					'issubof' => [
-						'label' => lng('domains.issubof'),
-						'desc' => lng('domains.issubofinfo'),
-						'type' => 'select',
-						'select_var' => $subtodomains,
-						'selected' => $result['ismainbutsubto']
-					],
 					'associated_info' => [
 						'label' => lng('domains.associated_with_domain'),
 						'type' => 'label',
@@ -104,7 +97,13 @@ return [
 						'type' => 'date',
 						'value' => $result['termination_date'],
 						'size' => 10
-					]
+					],
+					'deactivated' => [
+						'label' => lng('admin.deactivated'),
+						'type' => 'checkbox',
+						'value' => '1',
+						'checked' => $result['deactivated']
+					],
 				]
 			],
 			'section_e' => [
