@@ -732,9 +732,6 @@ return [
 		'aliasdomains' => 'Alias domini',
 		'redirectifpathisurl' => 'Codice di redirezione (Predefinito: vuoto)',
 		'redirectifpathisurlinfo' => 'È necessario selezionare uno di questi se hai inserito un URL come percorso',
-		'issubof' => 'Questo dominio è un sottodominio di un altro dominio',
-		'issubofinfo' => 'Devi impostare correttamente questo dominio se si desidera aggiungere un sottodominio come dominio completo (es. si vuole aggiungere "www.domain.tld", devi selezionare qui "domain.tld")',
-		'nosubtomaindomain' => 'No sottodominio di un dominio completo',
 		'ipandport_multi' => [
 			'title' => 'Indirizzi IP',
 			'description' => 'Specifica uno o più indirizzi IP per il dominio.<br /><br /><div class="text-danger">NOTA: L\'indirizzo IP non può essere modificato quando il dominio è configurato come <strong>alias-domain</strong> di un altro dominio.</div>',
@@ -1196,7 +1193,6 @@ Cordiali Saluti, Team Froxlor',
 		'admin_quotas_reallywipe' => 'Sei sicuro di voler cancellare tutti i limiti dalla tabella mail_users? Questa operazione non può essere annullata!',
 		'admin_quotas_reallyenforce' => 'Sei sicuro di voler impostare il limite predefinito a tutti gli utenti? Questa operazione non può essere annullata!',
 		'phpsetting_reallydelete' => 'Do you really want to delete these settings? All domains which use these settings currently will be changed to the default config.',
-		'remove_subbutmain_domains' => 'Rimuover anche i domini che sono stati aggiunti come domini completi, ma quali sono i sottodomini di questo dominio?',
 		'customer_reallyunlock' => 'Sei sicuro di voler sbloccare il cliente %s?',
 		'admin_customer_alsoremovemail' => 'Eliminare completamente i dati della posta elettronica dal filesystem??',
 		'admin_customer_alsoremoveftphomedir' => 'Rimuovere anche la cartella homedir dell\'utente FTP?',
